@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,13 +14,17 @@ use warnings;
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::DateTime',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
-    'Kernel::System::Log',
+    'Kernel::System::Priority',
+    'Kernel::System::Queue',
+    'Kernel::System::SLA',
     'Kernel::System::Service',
+    'Kernel::System::State',
     'Kernel::System::Ticket',
     'Kernel::System::Ticket::Article',
-    'Kernel::System::DateTime',
+    'Kernel::System::Type',
     'Kernel::System::User',
 );
 
@@ -178,6 +182,13 @@ sub Run {
     {
         $State = $ConfigObject->Get('PostmasterFollowUpStateClosed');
     }
+
+    if ( $GetParam{'X-OTRS-FollowUp-StateID'} ) {
+        $GetParam{'X-OTRS-FollowUp-State'} = $Kernel::OM->Get('Kernel::System::State')->StateLookup(
+            StateID => $GetParam{'X-OTRS-FollowUp-StateID'},
+        );
+    }
+
     if ( $GetParam{'X-OTRS-FollowUp-State'} ) {
         $State = $GetParam{'X-OTRS-FollowUp-State'};
     }
@@ -254,6 +265,11 @@ sub Run {
     }
 
     # set priority
+    if ( $GetParam{'X-OTRS-FollowUp-PriorityID'} ) {
+        $GetParam{'X-OTRS-FollowUp-Priority'} = $Kernel::OM->Get('Kernel::System::Priority')->PriorityLookup(
+            PriorityID => $GetParam{'X-OTRS-FollowUp-PriorityID'},
+        );
+    }
     if ( $GetParam{'X-OTRS-FollowUp-Priority'} ) {
 
         $TicketObject->TicketPrioritySet(
@@ -272,6 +288,12 @@ sub Run {
     }
 
     # set queue
+    if ( $GetParam{'X-OTRS-FollowUp-QueueID'} ) {
+        $GetParam{'X-OTRS-FollowUp-Queue'} = $Kernel::OM->Get('Kernel::System::Queue')->QueueLookup(
+            QueueID => $GetParam{'X-OTRS-FollowUp-QueueID'},
+        );
+    }
+
     if ( $GetParam{'X-OTRS-FollowUp-Queue'} ) {
 
         $TicketObject->TicketQueueSet(
@@ -308,6 +330,11 @@ sub Run {
     }
 
     # set ticket type
+    if ( $GetParam{'X-OTRS-FollowUp-TypeID'} ) {
+        $GetParam{'X-OTRS-FollowUp-Type'}
+            = $Kernel::OM->Get('Kernel::System::Type')->TypeLookup( TypeID => $GetParam{'X-OTRS-FollowUp-TypeID'} );
+    }
+
     if ( $GetParam{'X-OTRS-FollowUp-Type'} ) {
 
         $TicketObject->TicketTypeSet(
@@ -327,16 +354,22 @@ sub Run {
 
     # Ticket service handling.
 
+    if ( $GetParam{'X-OTRS-FollowUp-ServiceID'} ) {
+        $GetParam{'X-OTRS-FollowUp-Service'} = $Kernel::OM->Get('Kernel::System::Service')->ServiceLookup(
+            ServiceID => $GetParam{'X-OTRS-FollowUp-ServiceID'},
+        );
+    }
+
     if ( $GetParam{'X-OTRS-FollowUp-Service'} ) {
 
         # Get all valid services.
         my %ValidServices = reverse $Kernel::OM->Get('Kernel::System::Service')->ServiceList(
-           Valid        => 1,
-           KeepChildren => $ConfigObject->Get('Ticket::Service::KeepChildren') // 0,
-           UserID       => $Param{InmailUserID},
+            Valid        => 1,
+            KeepChildren => $ConfigObject->Get('Ticket::Service::KeepChildren') // 0,
+            UserID       => $Param{InmailUserID},
         );
 
-        if (!$ValidServices{$GetParam{'X-OTRS-FollowUp-Service'}}) {
+        if ( !$ValidServices{ $GetParam{'X-OTRS-FollowUp-Service'} } ) {
 
             # If service with given name does not exist or is invalid don't set it if not active.
 
@@ -371,6 +404,12 @@ sub Run {
     }
 
     # set ticket sla
+    if ( $GetParam{'X-OTRS-FollowUp-SLAID'} ) {
+        $GetParam{'X-OTRS-FollowUp-SLA'} = $Kernel::OM->Get('Kernel::System::SLA')->SLALookup(
+            SLAID => $GetParam{'X-OTRS-FollowUp-SLAID'},
+        );
+    }
+
     if ( $GetParam{'X-OTRS-FollowUp-SLA'} ) {
 
         $TicketObject->TicketSLASet(
@@ -582,6 +621,11 @@ sub Run {
     my %CommunicationLogSkipAttributes = (
         Body       => 1,
         Attachment => 1,
+
+        # Avoid possible errors on trying to store binary data in db.
+        # This can happen if there were (partial) errors in decryption, leading
+        # to the decrypted body still containing a binary key/cert.
+        'X-OTRS-BodyDecrypted' => 1,
     );
 
     ATTRIBUTE:
